@@ -47,7 +47,11 @@ impl Cli {
         let mut rule_file = RuleFile::new(None);
         if let Some(files) = args.values_of("melt") {
             for file in files {
-                rule_file.melt(&Path::new(file))?;
+                let path = &Path::new(file);
+                if !path.exists() {
+                    return Err(RadError::InvalidCommandOption(format!("File, \"{}\" doesn't exist, therefore cannot be melted.", path.display())))
+                }
+                rule_file.melt(path)?;
             }
         }
         // ========
@@ -77,6 +81,10 @@ impl Cli {
 
             for file in files {
                 processor.set_file(file);
+                let path = &Path::new(file);
+                if !path.exists() {
+                    return Err(RadError::InvalidCommandOption(format!("File, \"{}\" doesn't exist, therefore cannot be read by r4d.", path.display())))
+                }
                 processor.from_file(Path::new(file), false)?;
             }
         } 
@@ -103,6 +111,9 @@ impl Cli {
             processor.from_stdin(false)?;
         }
 
+        // Print result
+        processor.print_result()?;
+
         if let Some(file) = args.value_of("freeze") {
             RuleFile::new(Some(processor.map.custom)).freeze(&Path::new(file))?;
         }
@@ -116,7 +127,7 @@ impl Cli {
 
     fn args_builder() -> clap::ArgMatches {
         clap_app!(R4d =>
-            (version: "0.4.5")
+            (version: "0.4.6")
             (author: "Simon Creek <simoncreek@tutanota.com>")
             (about: "R4d is a modern macro processor made with rust")
             (@arg FILE: ... "Files to execute processing")
