@@ -1,5 +1,6 @@
 use crate::error::RadError;
 use crate::consts::*;
+use crate::utils::Utils;
 
 pub struct Lexor {
     previous_char : Option<char>,
@@ -50,9 +51,6 @@ impl Lexor {
             Cursor::Name => {
                 result = self.branch_name(ch);
             }
-            Cursor::NameToArg => {
-                result = self.branch_name_to_arg(ch);
-            }
             Cursor::Arg => {
                 result = self.branch_arg(ch);
             } // end arg match
@@ -97,11 +95,10 @@ impl Lexor {
     fn branch_name(&mut self, ch: char) -> LexResult {
         let mut result: LexResult;
 
-        // Start arg if parenthesis was given,
-        // whitespaces are ignored and don't trigger exit
-        if ch == ' ' {
-            self.cursor = Cursor::NameToArg;
-            result = LexResult::Ignore;
+        // Blank characters are nvalid
+        if Utils::is_blank_char(ch) {
+            self.cursor = Cursor::None;
+            result = LexResult::ExitFrag;
         } 
         // Left parenthesis trigger macro invocation
         else if ch == '(' {
@@ -122,31 +119,6 @@ impl Lexor {
         result
     }
 
-    /// Space between name and args
-    /// e.g.
-    /// $define ()
-    ///        |-> This is the name to args characters
-    fn branch_name_to_arg(&mut self, ch: char) -> LexResult {
-        let result: LexResult;
-
-        // White space or tab character is ignored
-        if ch == ' ' || ch == '\t' {
-            result = LexResult::Ignore;
-        } 
-        // Parenthesis start arguments
-        else if ch == '(' {
-            self.cursor = Cursor::Arg;
-            self.paren_count = 1;
-            result = LexResult::StartFrag;
-        } 
-        // Other characters are invalid
-        else {
-            self.cursor = Cursor::None;
-            result = LexResult::ExitFrag;
-        }
-        result
-    }
-
     // Double quote rule is somewhat suspicious?
     fn branch_arg(&mut self, ch: char) -> LexResult {
         let mut result: LexResult = LexResult::AddToFrag(Cursor::Arg);
@@ -203,6 +175,5 @@ pub enum LexResult {
 pub enum Cursor {
     None,
     Name,
-    NameToArg,
     Arg,
 }
